@@ -36,12 +36,19 @@ public:
     bool teardown() override;
     bool isEncrypted() const override;
 
+    bool canCheck() const override;
+    bool check() override;
+    bool canRepair() const override;
+    bool repair() override;
+
 Q_SIGNALS:
     void accessibilityChanged(bool accessible, const QString &udi) override;
     void setupDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
     void teardownDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
     void setupRequested(const QString &udi) override;
     void teardownRequested(const QString &udi) override;
+    void repairRequested(const QString &udi) override;
+    void repairDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
 
 public Q_SLOTS:
     Q_SCRIPTABLE Q_NOREPLY void passphraseReply(const QString &passphrase);
@@ -56,6 +63,8 @@ private Q_SLOTS:
     void slotSetupDone(int error, const QString &errorString);
     void slotTeardownRequested();
     void slotTeardownDone(int error, const QString &errorString);
+    void slotRepairRequested();
+    void slotRepairDone(int error, const QString &errorString);
 
     void checkAccessibility();
 
@@ -75,10 +84,13 @@ private:
     QString generateReturnObjectPath();
     QString clearTextPath() const;
 
+    QString dbusPath() const;
+
 private:
     bool m_isAccessible;
     bool m_setupInProgress;
     bool m_teardownInProgress;
+    bool m_repairInProgress;
     bool m_passphraseRequested;
     QString m_lastReturnObject;
 
